@@ -51,9 +51,7 @@ class HandleRisk:
                 "Error getting finding list in handle risk: {0}".format(str(e))
             )
 
-    def _filter_engagements(
-        self, engagements, service, endings_to_exclude, risk_config
-    ):
+    def _filter_engagements(self, engagements, service, risk_config):
         filtered_engagements = []
         min_word_length = risk_config["HANDLE_SERVICE_NAME"]["MIN_WORD_LENGTH"]
         words = [
@@ -65,21 +63,22 @@ class HandleRisk:
         ]
         check_words_regex = risk_config["HANDLE_SERVICE_NAME"]["REGEX_CHECK_WORDS"]
         min_word_amount = risk_config["HANDLE_SERVICE_NAME"]["MIN_WORD_AMOUNT"]
+        endings = risk_config["HANDLE_SERVICE_NAME"]["CHECK_ENDING"]
 
         for engagement in engagements:
-            if service.lower() in engagement.name.lower():
+            if service.lower() == engagement.name.lower():
                 filtered_engagements += [engagement.name]
             elif re.search(check_words_regex, engagement.name.lower()) and (
                 sum(1 for word in words if word.lower() in engagement.name.lower())
                 >= min_word_amount
             ):
                 filtered_engagements += [engagement.name]
-        if endings_to_exclude:
-            filtered_engagements = [
-                engagement
-                for engagement in filtered_engagements
-                if not any(engagement.endswith(ending) for ending in endings_to_exclude)
-            ]
+            elif endings:
+                if any(
+                    (service.lower() + ending.lower() == engagement.name.lower())
+                    for ending in endings
+                ):
+                    filtered_engagements += [engagement.name]
 
         return filtered_engagements
 
@@ -144,16 +143,10 @@ class HandleRisk:
         service_list = []
 
         if risk_config["HANDLE_SERVICE_NAME"]["ENABLED"].lower() == "true":
-            exclusive_endings = risk_config["HANDLE_SERVICE_NAME"]["EXCLUSIVE_ENDING"]
-            endings_to_exclude = [
-                ending
-                for ending in exclusive_endings
-                if not pipeline_name.endswith(ending)
-            ]
             service = next(
                 (
                     pipeline_name.replace(ending, "")
-                    for ending in exclusive_endings
+                    for ending in risk_config["HANDLE_SERVICE_NAME"]["CHECK_ENDING"]
                     if pipeline_name.endswith(ending)
                 ),
                 pipeline_name,
@@ -171,7 +164,7 @@ class HandleRisk:
                     service_code, dict_args, secret_tool, remote_config
                 )
                 service_list += self._filter_engagements(
-                    engagements, service, endings_to_exclude, risk_config
+                    engagements, service, risk_config
                 )
 
         service_list += [service]
