@@ -19,26 +19,35 @@ result = []
 
 
 class TrufflehogRun(ToolGateway):
-    def install_tool(self, agent_os, agent_temp_dir) -> any:
+    def install_tool(self, agent_os, agent_temp_dir, tool_version) -> any:
         reg_exp_os = r"Windows"
         check_os = re.search(reg_exp_os, agent_os)
+        reg_exp_tool = fr"{tool_version}"
         if check_os:
-            self.run_install_win(agent_temp_dir)
-        else:
-            command = f"trufflehog --version"
+            command = f"{agent_temp_dir}/trufflehog.exe --version"
+            subprocess.run(command, shell=True)
             result = subprocess.run(command, capture_output=True, shell=True)
             output = result.stderr.strip()
-            reg_exp = r"not found"
-            check_tool = re.search(reg_exp, output.decode("utf-8"))
-            if check_tool:
-                self.run_install()
+            check_tool = re.search(reg_exp_tool, output.decode("utf-8"))
+            if not check_tool:
+                self.run_install_win(agent_temp_dir, tool_version)
+                subprocess.run(command, shell=True)
+        else:
+            command = f"trufflehog --version"
+            subprocess.run(command, shell=True)
+            result = subprocess.run(command, capture_output=True, shell=True)
+            output = result.stderr.strip()
+            check_tool = re.search(reg_exp_tool, output.decode("utf-8"))
+            if not check_tool:
+                self.run_install(tool_version)
+                subprocess.run(command, shell=True)
 
-    def run_install(self):
-        command = f"curl -sSfL https://raw.githubusercontent.com/trufflesecurity/trufflehog/main/scripts/install.sh | sh -s -- -b /usr/local/bin"
-        subprocess.run(command, capture_output=True, shell=True)
+    def run_install(self, tool_version):
+        command = f"curl -sSfL https://raw.githubusercontent.com/trufflesecurity/trufflehog/main/scripts/install.sh | sh -s -- -b /usr/local/bin v{tool_version}"
+        res = subprocess.run(command, capture_output=True, shell=True)
 
-    def run_install_win(self, agent_temp_dir):
-        command_complete = f"powershell -Command [Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12; [Net.ServicePointManager]::SecurityProtocol; New-Item -Path {agent_temp_dir} -ItemType Directory -Force; Invoke-WebRequest -Uri 'https://raw.githubusercontent.com/trufflesecurity/trufflehog/main/scripts/install.sh' -OutFile {agent_temp_dir}\install_trufflehog.sh; bash {agent_temp_dir}\install_trufflehog.sh -b C:/Trufflehog/bin; $env:Path += ';C:/Trufflehog/bin'; C:/Trufflehog/bin/trufflehog.exe --version"
+    def run_install_win(self, agent_temp_dir, tool_version):
+        command_complete = f"powershell -Command [Net.ServicePointManager]::SecurityProtocol = [Net.SecurityProtocolType]::Tls12; [Net.ServicePointManager]::SecurityProtocol; New-Item -Path {agent_temp_dir} -ItemType Directory -Force; Invoke-WebRequest -Uri 'https://github.com/trufflesecurity/trufflehog/releases/download/v{tool_version}/trufflehog_{tool_version}_windows_amd64.tar.gz' -OutFile {agent_temp_dir}/trufflehog.tar.gz -UseBasicParsing; tar -xzf {agent_temp_dir}/trufflehog.tar.gz -C {agent_temp_dir}; Remove-Item {agent_temp_dir}/trufflehog.tar.gz; $env:Path += '; + {agent_temp_dir}'; & {agent_temp_dir}/trufflehog.exe --version"
         process = subprocess.Popen(
             command_complete, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=True
         )
@@ -52,11 +61,12 @@ class TrufflehogRun(ToolGateway):
         repository_name,
         config_tool,
         secret_tool,
-        secret_external_checks
+        secret_external_checks,
+        agent_temp_dir
     ):
         trufflehog_command = "trufflehog"
         if "Windows" in agent_os:
-            trufflehog_command = "C:/Trufflehog/bin/trufflehog.exe"
+            trufflehog_command = f"{agent_temp_dir}/trufflehog.exe"
         with open(f"{agent_work_folder}/excludedPath.txt", "w") as file:
             file.write("\n".join(config_tool.exclude_path))
         exclude_path = f"{agent_work_folder}/excludedPath.txt"
@@ -102,6 +112,7 @@ class TrufflehogRun(ToolGateway):
             include_paths.append(file_path)
             with open(file_path, "w") as file:
                 for file_pr_path in chunk:
+                    file_pr_path = str(file_pr_path).replace("/","\\\\")
                     file.write(f"{file_pr_path.strip()}\n")
         return include_paths
 
@@ -140,8 +151,7 @@ class TrufflehogRun(ToolGateway):
                 original_where = original_where.replace("\\", "/")
                 where_text = original_where.replace(agent_work_folder, "")
                 find["SourceMetadata"]["Data"]["Filesystem"]["file"] = where_text
-                name = find["ExtraData"]["name"] if find["ExtraData"] != None else None
-                find["Id"] = "MISSCONFIGURATION_SCANNING" if name != None and "Actuator" in name else "SECRET_SCANNING"
+                find["Id"] = "MISSCONFIGURATION_SCANNING" if "exposure" in find["Raw"] else "SECRET_SCANNING"
                 json_str = json.dumps(find)
                 file.write(json_str + '\n')
         return findings, file_findings
